skhubness.neighbors.KNeighborsRegressor
=======================================

.. currentmodule:: skhubness.neighbors

.. autoclass:: KNeighborsRegressor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~KNeighborsRegressor.__init__
      ~KNeighborsRegressor.fit
      ~KNeighborsRegressor.get_params
      ~KNeighborsRegressor.kcandidates
      ~KNeighborsRegressor.kneighbors
      ~KNeighborsRegressor.kneighbors_graph
      ~KNeighborsRegressor.predict
      ~KNeighborsRegressor.score
      ~KNeighborsRegressor.set_params
   
   

   
   
   